Crate delta_kernel_derive

Crate delta_kernel_derive 

Macros

column_name_segments
Builds &[&str] from the arguments to column_name!. Each string-literal argument is a dot-separated path, split into individual segments; every other (constant) argument is taken as a single segment, validated at const-eval time. All segments must match [a-zA-Z0-9_]+.

Attribute Macros

internal_api
Mark items as internal_api to make them public iff the internal-api feature is enabled.

Derive Macros

IntoEngineData
Derive an IntoEngineData trait for a struct that has all fields implement TryInto<Scalar>.
IntoStructData
Derive From conversions into StructData and Scalar for a rust struct.
ToSchema
Derive a delta_kernel::schemas::ToSchema implementation for the annotated struct. The actual field names in the schema (and therefore of the struct members) are all mandated by the Delta spec, and so the user of this macro is responsible for ensuring that e.g. Metadata::schema_string is the snake_case-ified version of schemaString from Delta’s Change Metadata action (this macro allows the use of standard rust snake_case, and will convert to the correct delta schema camelCase version).
TryFromStructData
Derive the inverse of IntoStructData: TryFrom conversions from StructData and Scalar for a rust struct.