Builds &[&str] from the arguments to column_name!. Each string-literal argument is a
dot-separated path, split into individual segments; every other (constant) argument is taken as
a single segment, validated at const-eval time. All segments must match [a-zA-Z0-9_]+.
Derive a delta_kernel::schemas::ToSchema implementation for the annotated struct. The actual
field names in the schema (and therefore of the struct members) are all mandated by the Delta
spec, and so the user of this macro is responsible for ensuring that
e.g. Metadata::schema_string is the snake_case-ified version of schemaString from Delta’s
Change Metadata
action (this macro allows the use of standard rust snake_case, and will convert to the correct
delta schema camelCase version).